<?php
/**
 * 	@package Magazinex
 */

/**
 *	Add custom body classes.
 *-----------------------------------------------------------------*/
function magazinex_body_classes( $classes ) {
	global $post;

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}
	if( ! get_option( 'show_avatars' ) ) {
		$classes[] = 'no-avatars';
	}
	if( is_customize_preview() ) {
		$classes[] = 'site-preview';
	}

	// Header Image.
	if( get_header_image() ) {
		$classes[] = 'header-image';
	}

	// Layout.
	if ( is_page_template( 'page-templates/frontpage.php' ) ) {
		$classes[] = 'front-page-template';
		$classes[] = magazinex_external_current_layout();
	}
	if ( is_singular( 'page' ) ) {
		$classes[] = esc_attr( get_post_meta( $post->ID, 'magazinex_post_layout', true ) );
	}
	if( is_page_template( array( 'page-templates/full-width.php', 'page-templates/frontpage.php' ) ) ) {
		$classes[] = 'full-width';
	}
	else {
		$classes[] = magazinex_external_current_layout();
		$classes[] = esc_attr( get_theme_mod('sidebar_position') );

	}

	return $classes;
}
add_filter( 'body_class', 'magazinex_body_classes' );

/**
 *	Add custom post classes.
 *-----------------------------------------------------------------*/
function magazinex_post_classes( $classes ) {
	global $post;

	// Layout.
	if( is_page_template( 'page-templates/frontpage.php' ) ) {
    		$class_key = array_search( 'page', $classes );
    		if ( false !== $class_key ) {
        			$classes[] = 'front-page';
    		}
	}

	$layout = magazinex_external_current_layout();

	if ( 'layout-default' != $layout ) {
		$class_key = array_search( 'post', $classes );
    		if ( false !== $class_key ) {
        			$classes[] = 'grid-item';
    		}
	}

	return $classes;
}
add_filter( 'post_class', 'magazinex_post_classes' );

/**
 *	Custom Excerpt lengths.
 *-----------------------------------------------------------------*/
function magazinex_external_excerpt_lengths( $lengths ) {
	return 20;
}
add_filter( 'excerpt_length', 'magazinex_external_excerpt_lengths', 98 );

/**
 *	Remove [...] from the excerpt.
 *-----------------------------------------------------------------*/
add_filter( 'excerpt_more', '__return_null' );

/**
 *	Custom more link text from the content.
 *-----------------------------------------------------------------*/
function magazinex_external_more_link_text( $link, $more_link_text ) {
	if( $more_link_text ) {
		$link = sprintf( '<a href="%s" class="more-link"><span>%s</span></a>', esc_url( get_permalink() ), esc_html__( 'Read more', 'magazinex-lite' ) );
	}

	return $link;
}
add_filter( 'the_content_more_link', 'magazinex_external_more_link_text', 10, 2 );

/**
 *	Get current layout options.
 *-----------------------------------------------------------------*/
function magazinex_external_current_layout() {
	if( is_home() ) {
		$layout = esc_attr( get_theme_mod( 'home_layout' ) );
	}
	elseif( is_page_template( 'page-templates/frontpage.php' ) ) {
		$layout = esc_attr( get_theme_mod( 'front_layout' ) );
	}
	elseif( is_archive() || is_search() || is_404() ) {
		$layout = esc_attr( get_theme_mod( 'archive_layout' ) );
	}
	else {
		$layout = esc_attr( 'layout-default' );
	}

	return $layout;
}

/**
 *	Set new content width with current layout.
 *-----------------------------------------------------------------*/
function magazinex_external_content_width() {
	$layout = magazinex_external_current_layout();

	if( is_page_template( array( 'template-fullwidth.php', 'page-templates/frontpage.php' ) ) ) {
		$GLOBALS['content_width'] = 980;
	}
	elseif( 'layout-two-columns' == $layout ) {
		$GLOBALS['content_width'] = 300;
	}
	elseif( 'layout-two-columns-fully' == $layout ) {
		$GLOBALS['content_width'] = 470;
	}
}
add_action( 'template_redirect', 'magazinex_external_content_width' );

/**
 *	Get custom post formats.
 *-----------------------------------------------------------------*/
function magazinex_external_post_formats( $post_id, $output ) {

	// Image Post.
	if( has_post_format( 'image', $post_id ) ) {
  		global $post, $posts;
  		ob_start();
  		ob_end_clean();
  		$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches);
		if ( 0 != $output ) {
			$image = $matches [1][0];
		}
		if( !empty( $image ) ) {
			$output   = '<img src="'. esc_url( $image ) .'" class="size-full" alt="'. esc_attr( $post->post_title ) .'" />';
		}
	}

	return $output;
}
add_filter( 'magazinex_post_formats', 'magazinex_external_post_formats', 10, 2 );

/**
 *	Add custom post classes.
 *-----------------------------------------------------------------*/
function magazinex_external_post_classes( $classes ) {
	$classes[] = 'clearfix';

	if( 'post' == get_post_type() && ! is_single() && ! has_post_thumbnail() ) {
		$classes[] = 'no-thumb';
	}
	
	if( is_single() & get_theme_mod( 'hide_post_share' ) ) {
		$classes[] = 'hide-post-share';
	}

	return $classes;
}
add_filter( 'post_class', 'magazinex_external_post_classes' );

/**
 *	Custom search form.
 *-----------------------------------------------------------------*/
function magazinex_external_search_form_modify( $html ) {
	return str_replace( 'placeholder="Search &hellip;"', 'placeholder="'. esc_attr__( 'Search and hit enter &hellip;', 'magazinex-lite' ) .'"', $html );
}
add_filter( 'get_search_form', 'magazinex_external_search_form_modify' );

/**
 *	Header Image.
 *-----------------------------------------------------------------*/
function magazinex_external_output_custom_header_image( $output ) {
		global $post;
		$header_bg = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full' );

	if( get_header_image() && ! has_post_thumbnail() ) {
		$output .= '.site-header { background-image: url("'. esc_url( get_header_image() ) .'"); }';
	}
	if( get_header_image() && has_post_thumbnail() ) {
		$output .= '.site-header { background-image: url("'. esc_url( $header_bg[0] ) .'"); }';
	}

	return $output;
}
add_filter( 'magazinex_customizer_css_output', 'magazinex_external_output_custom_header_image' );