<?php
/**
 * Tabs Widget: recent posts, popular and picked posts
 */

if ( ! class_exists( 'MAGAZINEX_Tabs_Widget' ) ) {
	class MAGAZINEX_Tabs_Widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'magazinex_tabs_widget',
				esc_html__( 'Tabs', 'magazinex-lite' ),
				array(
					'description' => esc_html__( 'Recent, Popular & Picked Posts.', 'magazinex-lite' )
				)
			);
		}

		/**
		 * Front-end display of widget.
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 */
		public function widget( $args, $instance ) {
			extract( $args );
			// Set vars
			$title		= isset( $instance['title'] ) ? $instance['title'] : '';
			$title		= apply_filters( 'widget_title', $instance['title'] );
			$number		= isset( $instance['number'] ) ? $instance['number'] : '';
			// Get current ID to exclude it
			if ( is_singular() ) {
				$exclude = array( get_the_ID() );
			} else {
				$exclude = NULL;
			}
			// Before title hook
			echo $before_widget;
				// Display title
				if ( $title ) {
					echo $before_title . $title . $after_title;
				} ?>
				<div class="tabs-widget clearfix">
					<div class="tabs-widget-inner clearfix">
						<ul class="tabs-widget-tabs clearfix">
							<li class="active"><a href="#" data-tab="#widget-recent-tab"><?php esc_attr_e( 'Recent Articles', 'magazinex-lite' ); ?></a></li>
							<?php if ( $sticky = get_option( 'sticky_posts' ) ) { ?>
								<li><a href="#" data-tab="#widget-picked-tab" class="last"><?php esc_attr_e( 'Picked Articles', 'magazinex-lite' ); ?></a></li>
							<?php } ?>
						</ul><!-- .tabs-widget-tabs -->
						<div id="widget-recent-tab" class="tabs-widget-tab active-tab clearfix">
							<ul class="widget-recent-list clearfix">
								<?php
								// Query Recent Posts
								global $post;

								$magazinex_query = new WP_Query( array(
									'post_type'	=> 'post',
									'posts_per_page'	=> $number,
									'orderby'		=> 'date',
									'no_found_rows'	=> true,
									'meta_key'	=> '_thumbnail_id',
									'post__not_in'	=> $exclude,
									'ignore_sticky_posts'	=> 1,
								) );

								if ( $magazinex_query->have_posts() ) :
									foreach( $magazinex_query->posts as $post ) : setup_postdata( $post );
									if ( has_post_thumbnail() ) { ?>
										<li class="clearfix">
											<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" class="clearfix thumbnail">
												<?php the_post_thumbnail(); ?>
											</a>
											<div class="excerpt">
												<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a><br /><?php echo wp_trim_words( get_the_content(), '7', '&hellip;' ); ?>
											</div>
										</li>
									<?php } ?>
									<?php
									endforeach;
								endif;
								wp_reset_postdata(); ?>
							</ul>
						</div><!-- tabs-widget-tab -->
						<?php if ( $sticky ) { ?>
							<div id="widget-picked-tab" class="tabs-widget-tab clearfix">
								<ul class="widget-recent-list clearfix">
								<?php
								// Query Sticky Posts
								global $post;

								$magazinex_query  = new WP_Query( array(
									'post_type'	=> 'post',
									'posts_per_page'	=> $number,
									'orderby'		=> 'date',
									'no_found_rows'	=> true,
									'meta_key'	=> '_thumbnail_id',
									'post__in' 		=> $sticky,
									'post__not_in'	=> $exclude,
								) );

								if ( $magazinex_query->have_posts() ) :
									foreach( $magazinex_query->posts as $post ) : setup_postdata( $post );
									if ( has_post_thumbnail() ) { ?>
										<li class="clearfix">
											<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>" class="clearfix thumbnail">
												<?php the_post_thumbnail(); ?>
											</a>
											<div class="excerpt">
												<a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a><br /><?php echo wp_trim_words( get_the_content(), '7', '&hellip;' ); ?>
											</div>
										</li>
									<?php } ?>
									<?php
									endforeach;
								endif;
								wp_reset_postdata(); ?>
							</ul>
							</div><!-- .tabs-widget-tab -->
						<?php } ?>
					</div><!-- .tabs-widget-inner -->
				</div><!-- .tabs-widget -->
			<?php echo $after_widget;
		}

		/**
		 * Sanitize widget form values as they are saved.
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 * @return array Updated safe values to be saved.
		 */
		function update( $new_instance, $old_instance ) {
			$instance			= $old_instance;
			$instance['title']		= sanitize_text_field( $new_instance['title'] );
			$instance['number']		= absint( $new_instance['number'] );
			return $instance;
		}

		/**
		 * Back-end widget form.
		 * @param array $instance Previously saved values from database.
		 */
		function form( $instance ) {

			$instance = wp_parse_args( ( array ) $instance, array(
				'title'		=> '',
				'number'		=> '3',
			));
			$title	= sanitize_text_field( $instance['title'] );
			$number	= absint( $instance['number'] ); ?>
			
			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php esc_attr_e( 'Title:', 'magazinex-lite' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title','magazinex-lite' ); ?>" type="text" value="<?php echo $title; ?>" />
			</p>
			<p>
				<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php esc_attr_e( 'Number to Show:', 'magazinex-lite' ); ?></label> 
				<input class="widefat" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" />
			</p>
			<?php
		}
	}
}

// Register the custom widget
if ( ! function_exists( 'register_magazinex_tabs_widget' ) ) {
	function register_magazinex_tabs_widget() {
		register_widget( 'MAGAZINEX_Tabs_Widget' );
	}
}
add_action( 'widgets_init', 'register_magazinex_tabs_widget' );