/**
 *	@package Magazinex
 */
( function( $ ) {
	'use strict';

	var magFunctions = {

		/**
		 * Define cache var
		 */
		cache: {},

		/**
		 * Main Function
		 */
		init: function() {
			this.cacheElements();
			this.bindEvents();
		},

		/**
		 * Cache Elements
		 */
		cacheElements: function() {
			this.cache.$window     	= $(window);
			this.cache.$document   	= $(document);

			this.cache.$body       	= $('body');
			this.cache.$menuWrap   	= $('#navigation');
			this.cache.$menuToggle 	= $('.menu-toggle');
			this.cache.$searchToggle 	= $('.search-header');
			this.cache.$searchWrap   	= $('#search-header-bar');
			this.cache.$adminbar   	= $('#wpadminbar');
			this.cache.dontClose   	= false;
		},

		/**
		 * Bind Events
		 */
		bindEvents: function() {

			// Get self
			var self = this;

			// Masonry.
			self.cache.$document.on('ready', function() {
				self.masonryInit();
			});

			// Scroll Top.
			self.cache.$document.on('ready', function() {
				self.scrollTop();
			});

    			// Toggle Search Form.
    			self.cache.$searchToggle.on("click", function() {
    				$(this).toggleClass('active');
        				$('#search-header-bar').slideToggle("fast");
    			});

			// Widget Tabs.
			self.cache.$document.on('ready', function() {
				$( '.tabs-widget-tabs a' ).on( 'click', function(event) {
					var $parentLi = $( this ).parent();
					if ( ! $parentLi.hasClass( 'active' ) ) {
						$( 'ul.tabs-widget-tabs li' ).removeClass( 'active' );
						$parentLi.addClass( 'active' );
						var data = $(this).data( 'tab' );
						$( '.tabs-widget-tab.active-tab' ).stop( true, true ).hide();
						$(this).removeClass( 'active-tab' );
						$(data).addClass( 'active-tab' );
						$(data).show();
					}
					return false;
				} );
			});
			

			// Fixed top bar.
    			self.cache.$window.scroll(function() {
    				var top = self.cache.$document.scrollTop();

            				if ( top < 508 && self.cache.$menuWrap.hasClass("is-sticky") ){
                				self.cache.$menuWrap.removeClass("is-sticky").addClass("default");
            				} else if ( top > 508 && self.cache.$menuWrap.hasClass("default") ) {
                				self.cache.$menuWrap.removeClass("default").addClass("is-sticky");
            				}
    			});
			
			// FitVids.
			self.cache.$document.on('ready post-load', function() {
				self.fitVidsInit();
			});

			// owlCarousel.
			self.cache.$document.on('ready post-load', function() {
				self.owlCarouselInit();
			});

			// Mobile Menu.
			self.cache.$menuToggle.on('click', function(e) {
				e.preventDefault();
				e.stopPropagation();
				self.mobileMenu();
			});
			self.cache.$document.on('click', 'body.pushed', function() {
				if ( false === self.cache.dontClose ) {
					self.mobileMenu();
				}
				self.cache.dontClose = false;
			});
			self.cache.$menuWrap.on('click', function(e) {
				self.cache.dontClose = true;
			});
		},

		// Initialize the FitVids script.
		fitVidsInit: function() {
			if ( ! $.fn.fitVids ) {
				return;
			};
			this.cache.$fitvids = $('.site-main');
			this.cache.$fitvids.fitVids();
		},

		// Scroll Top function.
		scrollTop: function() {
			var $scrollTopLink = $( 'a.scroll-top' );

			this.cache.$window.scroll(function () {
				if ( $( this ).scrollTop() > 100 ) {
					$scrollTopLink.addClass( 'show' );
				} else {
					$scrollTopLink.removeClass( 'show' );
				}
			} );

			$scrollTopLink.on( 'click', function() {
				$( 'html, body' ).animate( {
					scrollTop : 0
				}, 400 );
				return false;
			} );

		},

		// Initialize the owlCarousel script.
		owlCarouselInit: function() {
			if ( ! $.fn.owlCarousel ) {
				return;
			}
			this.cache.$owlcarousel = $('.post-media').find('.gallery');
			if ( this.cache.$owlcarousel.length < 1 ) {
				return;
			};
			var args = {
				singleItem: true,
				autoPlay: false,
				pagination: false,
				navigation: true,
				navigationText: ['<span class="fa fa-angle-left"></span>', '<span class="fa fa-angle-right"></span>'],
				autoHeight: true
			};
			this.cache.$owlcarousel.owlCarousel(args);
		},

		// Initialize the Masonry layout.
		masonryInit: function() {
			if ( ! $.fn.masonry || 'undefined' === typeof imagesLoaded ) {
				return;
			};
			this.cache.$postWrap = $('.post-container');
			if ( this.cache.$postWrap.length < 1 ) {
				return;
			};

			// Fire Masonry after images are loaded.
			this.cache.$postWrap.imagesLoaded( function() {
				magFunctions.cache.$postWrap.masonry({
					itemSelector : 'article'
				});
			});

			// Infinite Scroll support.
			if ( this.cache.$body.hasClass( 'infinite-scroll' ) ) {
				this.cache.$document.on('post-load', function() {
					var $appended = $('.infinite-wrap article');
					magFunctions.cache.$postWrap.imagesLoaded(function() {
						magFunctions.cache.$postWrap.masonry( 'appended', $appended ).masonry({transitionDuration: 0});
						$appended.unwrap();
					});
				});
			};
		},

		mobileMenu: function() {
			var $body = this.cache.$body,
				$menuWrap = this.cache.$menuWrap,
				$adminbar = this.cache.$adminbar;
			if( ! $body.hasClass('pushed') ) {
				$adminbar.removeClass('moved');
				$menuWrap.hide();
			};

			if ( $menuWrap.hasClass('on-canvas') ) {
				$body.removeClass('pushed');
				$menuWrap.removeClass('on-canvas');
			} else {
				$body.addClass('pushed');
				$menuWrap.addClass('on-canvas').show();
				$adminbar.addClass('moved');
			};
		}
	};

	magFunctions.init();
	
})(jQuery);